@@ -391,6 +391,30 @@ class Transform:
     ScaleUp = 1 << 1
     ScaleDown = 1 << 2
     Projective = 1 << 3
+class GetCrtcTransformReply(xcffib.Reply):
+    xge = False
+    def __init__(self, unpacker):
+        if isinstance(unpacker, xcffib.Protobj):
+            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
+        xcffib.Reply.__init__(self, unpacker)
+        base = unpacker.offset
+        unpacker.unpack("xx2x4x")
+        self.pending_transform = render.TRANSFORM(unpacker)
+        self.has_transforms, = unpacker.unpack("B3x")
+        unpacker.pad(render.TRANSFORM)
+        self.current_transform = render.TRANSFORM(unpacker)
+        self.pending_len, self.pending_nparams, self.current_len, self.current_nparams = unpacker.unpack("4xHHHH")
+        unpacker.pad("c")
+        self.pending_filter_name = xcffib.List(unpacker, "c", self.pending_len)
+        unpacker.pad("i")
+        self.pending_params = xcffib.List(unpacker, "i", self.pending_nparams)
+        unpacker.pad("c")
+        self.current_filter_name = xcffib.List(unpacker, "c", self.current_len)
+        unpacker.pad("i")
+        self.current_params = xcffib.List(unpacker, "i", self.current_nparams)
+        self.bufsize = unpacker.offset - base
+class GetCrtcTransformCookie(xcffib.Cookie):
+    reply_type = GetCrtcTransformReply
 class GetPanningReply(xcffib.Reply):
     xge = False
     def __init__(self, unpacker):
@@ -909,12 +933,13 @@ class randrExtension(xcffib.Extension):
         buf.write(struct.pack("=H", filter_len))
         buf.write(struct.pack("=2x", ))
         buf.write(xcffib.pack_list(filter_name, "c"))
+        buf.write(struct.pack("=4x", ))
         buf.write(xcffib.pack_list(filter_params, "i"))
         return self.send_request(26, buf, is_checked=is_checked)
-    def GetCrtcTransform(self, crtc, is_checked=False):
+    def GetCrtcTransform(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
-        return self.send_request(27, buf, is_checked=is_checked)
+        return self.send_request(27, buf, GetCrtcTransformCookie, is_checked=is_checked)
     def GetPanning(self, crtc, is_checked=True):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
